@@ -3,8 +3,8 @@ import warnings
 from braintree.resource import Resource
 from braintree.address import Address
 from braintree.configuration import Configuration
-from braintree.transparent_redirect import TransparentRedirect
 from braintree.credit_card_verification import CreditCardVerification
+from enum import Enum
 
 class CreditCard(Resource):
     """
@@ -28,6 +28,7 @@ class CreditCard(Resource):
                 "postal_code": "60606",
                 "region": "IL",
                 "country_name": "United States of America"
+                "phone_number": "312-123-4567"
             },
             "options": {
                 "verify_card": True,
@@ -38,7 +39,7 @@ class CreditCard(Resource):
         print(result.credit_card.token)
         print(result.credit_card.masked_number)
 
-    For more information on CreditCards, see https://developers.braintreepayments.com/reference/request/credit-card/create/python
+    For more information on CreditCards, see https://developer.paypal.com/braintree/docs/reference/request/credit-card/create/python
 
     """
     class CardType(object):
@@ -52,6 +53,8 @@ class CreditCard(Resource):
         * Braintree.CreditCard.Discover
         * Braintree.CreditCard.Electron
         * Braintree.CreditCard.Elo
+        * Braintree.CreditCard.Hiper
+        * Braintree.CreditCard.Hipercard
         * Braintree.CreditCard.JCB
         * Braintree.CreditCard.Laser
         * Braintree.CreditCard.UK_Maestro
@@ -70,6 +73,8 @@ class CreditCard(Resource):
         Discover = "Discover"
         Electron = "Electron"
         Elo = "Elo"
+        Hiper = "Hiper"
+        Hipercard = "Hipercard"
         JCB = "JCB"
         Laser = "Laser"
         UK_Maestro = "UK Maestro"
@@ -91,6 +96,7 @@ class CreditCard(Resource):
         International = "international"
         US = "us"
 
+    # NEXT_MAJOR_VERSION this can be an enum! they were added as of python 3.4 and we support 3.5+
     class CardTypeIndicator(object):
         """
         Constants representing the three states for the card type indicator attributes
@@ -103,23 +109,29 @@ class CreditCard(Resource):
         No = "No"
         Unknown = "Unknown"
 
+    class DebitNetwork(Enum):
+        """
+        Constants representing the debit networks used for processing a pinless debit transaction
+
+        * braintree.CreditCard.DebitNetwork.Accel
+        * braintree.CreditCard.DebitNetwork.Maestro
+        * braintree.CreditCard.DebitNetwork.Nyce
+        * braintree.CreditCard.DebitNetwork.Pulse
+        * braintree.CreditCard.DebitNetwork.Star
+        * braintree.CreditCard.DebitNetwork.Star_Access
+        """
+        Accel = "ACCEL"
+        Maestro= "MAESTRO"
+        Nyce = "NYCE"
+        Pulse = "PULSE"
+        Star = "STAR"
+        Star_Access = "STAR_ACCESS"
+
     Commercial = DurbinRegulated = Debit = Healthcare = \
             CountryOfIssuance = IssuingBank = Payroll = Prepaid = ProductId = CardTypeIndicator
 
     @staticmethod
-    def confirm_transparent_redirect(query_string):
-        """
-        Confirms a transparent redirect request. It expects the query string from the
-        redirect request. The query string should _not_ include the leading "?" character. ::
-
-            result = braintree.CreditCard.confirm_transparent_redirect_request("foo=bar&id=12345")
-        """
-
-        warnings.warn("Please use TransparentRedirect.confirm instead", DeprecationWarning)
-        return Configuration.gateway().credit_card.confirm_transparent_redirect(query_string)
-
-    @staticmethod
-    def create(params={}):
+    def create(params=None):
         """
         Create a CreditCard.
 
@@ -131,11 +143,12 @@ class CreditCard(Resource):
             })
 
         """
-
+        if params is None:
+            params = {}
         return Configuration.gateway().credit_card.create(params)
 
     @staticmethod
-    def update(credit_card_token, params={}):
+    def update(credit_card_token, params=None):
         """
         Update an existing CreditCard
 
@@ -146,7 +159,8 @@ class CreditCard(Resource):
             })
 
         """
-
+        if params is None:
+            params = {}
         return Configuration.gateway().credit_card.update(credit_card_token, params)
 
     @staticmethod
@@ -183,14 +197,6 @@ class CreditCard(Resource):
         """
         return Configuration.gateway().credit_card.find(credit_card_token)
 
-    @staticmethod
-    def forward(credit_card_token, receiving_merchant_id):
-        """
-        This method has been deprecated. Please consider the Grant API instead.
-        """
-
-        return Configuration.gateway().credit_card.forward(credit_card_token, receiving_merchant_id)
-
     @staticmethod
     def from_nonce(nonce):
         """
@@ -224,16 +230,20 @@ class CreditCard(Resource):
             "locality",
             "postal_code",
             "region",
-            "street_address"
+            "street_address",
+            "phone_number"
         ]
 
         options = [
+            "fail_on_duplicate_payment_method",
+            "fail_on_duplicate_payment_method_for_customer",
             "make_default",
+            "skip_advanced_fraud_checking",
+            "venmo_sdk_session",  # NEXT_MJOR_VERSION remove venmo_sdk_session
+            "verification_account_type",
+            "verification_amount",
             "verification_merchant_account_id",
             "verify_card",
-            "verification_amount",
-            "venmo_sdk_session",
-            "fail_on_duplicate_payment_method",
             {
                 "adyen":[
                     "overwrite_brand",
@@ -242,6 +252,14 @@ class CreditCard(Resource):
             }
         ]
 
+        three_d_secure_pass_thru = [
+            "cavv",
+            "ds_transaction_id",
+            "eci_flag",
+            "three_d_secure_version",
+            "xid"
+        ]
+
         signature = [
             "billing_address_id",
             "cardholder_name",
@@ -249,18 +267,20 @@ class CreditCard(Resource):
             "expiration_date",
             "expiration_month",
             "expiration_year",
-            "device_session_id",
-            "fraud_merchant_id",
             "number",
             "token",
-            "venmo_sdk_payment_method_code",
+            "venmo_sdk_payment_method_code", # NEXT_MJOR_VERSION remove venmo_sdk_payment_method_code
             "device_data",
             "payment_method_nonce",
+            "device_session_id", "fraud_merchant_id", # NEXT_MAJOR_VERSION remove device_session_id and fraud_merchant_id
             {
                 "billing_address": billing_address_params
             },
             {
                 "options": options
+            },
+            {
+                "three_d_secure_pass_thru": three_d_secure_pass_thru
             }
         ]
 
@@ -276,38 +296,6 @@ class CreditCard(Resource):
 
         return signature
 
-    @staticmethod
-    def transparent_redirect_create_url():
-        """
-        Returns the url to use for creating CreditCards through transparent redirect.
-        """
-        warnings.warn("Please use TransparentRedirect.url instead", DeprecationWarning)
-        return Configuration.gateway().credit_card.transparent_redirect_create_url()
-
-    @staticmethod
-    def tr_data_for_create(tr_data, redirect_url):
-        """
-        Builds tr_data for CreditCard creation.
-        """
-
-        return Configuration.gateway().credit_card.tr_data_for_create(tr_data, redirect_url)
-
-    @staticmethod
-    def tr_data_for_update(tr_data, redirect_url):
-        """
-        Builds tr_data for CreditCard updating.
-        """
-
-        return Configuration.gateway().credit_card.tr_data_for_update(tr_data, redirect_url)
-
-    @staticmethod
-    def transparent_redirect_update_url():
-        """
-        Returns the url to be used for updating CreditCards through transparent redirect.
-        """
-        warnings.warn("Please use TransparentRedirect.url instead", DeprecationWarning)
-        return Configuration.gateway().credit_card.transparent_redirect_update_url()
-
     def __init__(self, gateway, attributes):
         Resource.__init__(self, gateway, attributes)
         self.is_expired = self.expired
@@ -326,6 +314,8 @@ class CreditCard(Resource):
 
     @property
     def expiration_date(self):
+        if not self.expiration_month or not self.expiration_year:
+            return None
         return self.expiration_month + "/" + self.expiration_year
 
     @property
@@ -333,5 +323,7 @@ class CreditCard(Resource):
         """
         Returns the masked number of the CreditCard.
         """
-        return self.bin + "******" + self.last_4
-
+        bin = self.bin_extended if hasattr(self, "bin_extended") else self.bin
+        mask_length = 16 - len(bin) - len(self.last_4)
+        mask = "*" * mask_length
+        return bin + mask + self.last_4
