@@ -7,6 +7,7 @@ from braintree.resource import Resource
 
 class CreditCardVerification(AttributeGetter):
 
+    # NEXT_MAJOR_VERSION this can be an enum! they were added as of python 3.4 and we support 3.5+
     class Status(object):
         """
         Constants representing transaction statuses. Available statuses are:
@@ -14,20 +15,18 @@ class CreditCardVerification(AttributeGetter):
         * braintree.CreditCardVerification.Status.Failed
         * braintree.CreditCardVerification.Status.GatewayRejected
         * braintree.CreditCardVerification.Status.ProcessorDeclined
-        * braintree.CreditCardVerification.Status.Unrecognized
         * braintree.CreditCardVerification.Status.Verified
         """
 
         Failed                 = "failed"
         GatewayRejected        = "gateway_rejected"
         ProcessorDeclined      = "processor_declined"
-        Unrecognized           = "unrecognized"
         Verified               = "verified"
 
     def __init__(self, gateway, attributes):
         AttributeGetter.__init__(self, attributes)
 
-        if "amount" in attributes and self.amount:
+        if "amount" in attributes and getattr(self, "amount", None):
             self.amount = Decimal(self.amount)
         else:
             self.amount = None
@@ -79,10 +78,37 @@ class CreditCardVerification(AttributeGetter):
                 "number", "cvv", "cardholder_name", "cvv", "expiration_date", "expiration_month",
                 "expiration_year", {"billing_address": billing_address_params}
             ]
+        external_vault_params = [
+                "previous_network_transaction_id",
+                "status"
+            ]
         options_params = [
                 "account_type", "amount", "merchant_account_id"
             ]
-        return [{"credit_card": credit_card_params}, {"options": options_params}]
+        risk_data_params = [
+                "customer_browser",
+                "customer_ip"
+            ]
+        three_d_secure_pass_thru_params = [
+                "eci_flag",
+                "cavv",
+                "xid",
+                "authentication_response",
+                "directory_response",
+                "cavv_algorithm",
+                "ds_transaction_id",
+                "three_d_secure_version"
+                ]
+
+        return [
+                {"credit_card": credit_card_params},
+                {"external_vault": external_vault_params},
+                "intended_transaction_source",
+                {"options": options_params},
+                "payment_method_nonce",
+                {"risk_data": risk_data_params},
+                "three_d_secure_authentication_id",
+                {"three_d_secure_pass_thru": three_d_secure_pass_thru_params}]
 
     def __eq__(self, other):
         if not isinstance(other, CreditCardVerification):
