@@ -18,7 +18,6 @@ class ErrorCodes(object):
         CountryCodeAlpha3IsNotAccepted = "91816"
         CountryCodeNumericIsNotAccepted = "91817"
         CountryNameIsNotAccepted = "91803"
-        ExtedAddressIsTooLong = "81804" # Deprecated
         ExtendedAddressIsInvalid = "91823"
         ExtendedAddressIsTooLong = "81804"
         FirstNameIsInvalid = "91819"
@@ -42,6 +41,9 @@ class ErrorCodes(object):
         StreetAddressIsTooLong = "81812"
         TooManyAddressesPerCustomer = "91818"
 
+    class AndroidPay(object):
+        AndroidPayCardsAreNotAccepted = "83708"
+
     class ApplePay(object):
         ApplePayCardsAreNotAccepted = "83501"
         CustomerIdIsRequiredForVaulting = "83502"
@@ -65,6 +67,8 @@ class ErrorCodes(object):
         InvalidToken = "83520"
         PrivateKeyMismatch = "93521"
         KeyMismatchStoringCertificate = "93522"
+        CustomerIdIsInvalid = "93528"
+        BillingAddressFormatIsInvalid = "93529"
 
     class AuthorizationFingerprint(object):
         MissingFingerprint = "93201"
@@ -76,13 +80,16 @@ class ErrorCodes(object):
         OptionsNotAllowedWithoutCustomer = "93207"
 
     class ClientToken(object):
-        MakeDefaultRequiresCustomerId = "92801"
-        VerifyCardRequiresCustomerId = "92802"
-        FailOnDuplicatePaymentMethodRequiresCustomerId = "92803"
         CustomerDoesNotExist = "92804"
-        ProxyMerchantDoesNotExist = "92805"
-        UnsupportedVersion = "92806"
+        FailOnDuplicatePaymentMethodRequiresCustomerId = "92803"
+        FailOnDuplicatePaymentMethodForCustomerRequiresCustomerId = "92805"
+        InvalidDomainFormat = "92011"
+        MakeDefaultRequiresCustomerId = "92801"
         MerchantAccountDoesNotExist = "92807"
+        ProxyMerchantDoesNotExist = "92805"
+        TooManyDomains = "92810"
+        UnsupportedVersion = "92806"
+        VerifyCardRequiresCustomerId = "92802"
 
     class CreditCard(object):
         BillingAddressConflict = "91701"
@@ -99,6 +106,7 @@ class ErrorCodes(object):
         CvvIsRequired = "81706"
         CvvVerificationFailed = "81736"
         DuplicateCardExists = "81724"
+        DuplicateCardExistsForCustomer = "81763"
         ExpirationDateConflict = "91708"
         ExpirationDateIsInvalid = "81710"
         ExpirationDateIsRequired = "81709"
@@ -106,7 +114,9 @@ class ErrorCodes(object):
         ExpirationMonthIsInvalid = "81712"
         ExpirationYearIsInvalid = "81713"
         InvalidParamsForCreditCardUpdate = "91745"
-        InvalidVenmoSDKPaymentMethodCode = "91727"
+        InvalidVenmoSDKPaymentMethodCode = "91727" # NEXT_MJOR_VERSION remove this code
+        LimitExceededforDuplicatePaymentMethodCheckForCustomer = "81764"
+        NetworkTokenizationAttributeCryptogramIsRequired = "81762"
         NumberHasInvalidLength = NumberLengthIsInvalid = "81716"
         NumberIsInvalid = "81715"
         NumberIsProhibited = "81750"
@@ -128,7 +138,7 @@ class ErrorCodes(object):
         TokenIsNotAllowed = "91721"
         TokenIsRequired = "91722"
         TokenIsTooLong = "91720"
-        VenmoSDKPaymentMethodCodeCardTypeIsNotAccepted = "91726"
+        VenmoSDKPaymentMethodCodeCardTypeIsNotAccepted = "91726" # NEXT_MJOR_VERSION remove this code
         VerificationNotSupportedOnThisMerchantAccount = "91730"
         VerificationAccountTypeIsInvald = "91757"
         VerificationAccountTypeNotSupported = "91758"
@@ -156,7 +166,6 @@ class ErrorCodes(object):
         FaxIsTooLong = "81607"
         FirstNameIsTooLong = "81608"
         IdIsInUse = "91609"
-        IdIsInvaild = "91610" # Deprecated
         IdIsInvalid = "91610"
         IdIsNotAllowed = "91611"
         IdIsRequired = "91613"
@@ -206,6 +215,7 @@ class ErrorCodes(object):
         FileTypeIsInvalid = "84903"
         FileIsMalformedOrEncrypted = "84904"
         FileIsTooLong = "84905"
+        FileIsEmpty = "84906"
 
     class Merchant(object):
         CountryCannotBeBlank = "83603"
@@ -337,6 +347,27 @@ class ErrorCodes(object):
         UnsupportedGrantType = "93805"
 
     class Verification(object):
+        ThreeDSecureAuthenticationIdIsInvalid = "942196"
+        ThreeDSecureAuthenticationIdDoesntMatchNonceThreeDSecureAuthentication = "942198"
+        ThreeDSecureTransactionPaymentMethodDoesntMatchThreeDSecureAuthenticationPaymentMethod = "942197"
+        ThreeDSecureAuthenticationIdWithThreeDSecurePassThruIsInvalid = "942199"
+        ThreeDSecureAuthenticationFailed = "94271"
+        ThreeDSecureTokenIsInvalid = "94268"
+        ThreeDSecureVerificationDataDoesntMatchVerify = "94270"
+        MerchantAccountDoesNotSupport3DSecure = "942169"
+        MerchantAcountDoesNotMatch3DSecureMerchantAccount = "94284"
+        AmountDoesNotMatch3DSecureAmount = "94285"
+        class ThreeDSecurePassThru(object):
+            EciFlagIsRequired = "942113"
+            EciFlagIsInvalid = "942114"
+            CavvIsRequired = "942116"
+            ThreeDSecureVersionIsRequired = "942117"
+            ThreeDSecureVersionIsInvalid = "942119"
+            AuthenticationResponseIsInvalid = "942120"
+            DirectoryResponseIsInvalid = "942121"
+            CavvAlgorithmIsInvalid = "942122"
+
+
         class Options(object):
             AmountCannotBeNegative = "94201"
             AmountFormatIsInvalid = "94202"
@@ -403,6 +434,11 @@ class ErrorCodes(object):
         IBANIsRequired = "83303"
         AccountHolderNameIsRequired = "83301"
 
+    class SepaDirectDebitAccount(object):
+        SepaDebitAccountPaymentMethodMandateTypeIsNotSupported = "87115"
+        SepaDebitAccountPaymentMethodCustomerIdIsInvalid = "87116"
+        SepaDebitAccountPaymentMethodCustomerIdIsRequired = "87117"
+
     class Subscription(object):
         BillingDayOfMonthCannotBeUpdated = "91918"
         BillingDayOfMonthIsInvalid = "91914"
@@ -469,15 +505,16 @@ class ErrorCodes(object):
             IdToRemoveIsInvalid = "92025"
 
     class Transaction(object):
+        AdjustmentAmountMustBeGreaterThanZero = "95605"
         AmountCannotBeNegative = "81501"
         AmountDoesNotMatch3DSecureAmount = "91585"
-        AmountDoesNotMatchIdealPaymentAmount = "915144"
         AmountIsInvalid = AmountFormatIsInvalid = "81503"
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
         AmountMustBeGreaterThanZero = "81531"
         AmountNotSupportedByProcessor = "815193"
         BillingAddressConflict = "91530"
+        BillingPhoneNumberIsInvalid = "915206"
         CannotBeVoided = "91504"
         CannotCancelRelease = "91562"
         CannotCloneCredit = "91543"
@@ -506,41 +543,31 @@ class ErrorCodes(object):
         CustomerDefaultPaymentMethodCardTypeIsNotAccepted = "81509"
         CustomerDoesNotHaveCreditCard = "91511"
         CustomerIdIsInvalid = "91510"
+        DiscountAmountCannotBeNegative = "915160"
+        DiscountAmountFormatIsInvalid = "915159"
+        DiscountAmountIsTooLarge = "915161"
+        ExchangeRateQuoteIdIsTooLong = "915229"
         FailedAuthAdjustmentAllowRetry = "95603"
         FailedAuthAdjustmentHardDecline = "95602"
         FinalAuthSubmitForSettlementForDifferentAmount = "95601"
         HasAlreadyBeenRefunded = "91512"
-        IdealPaymentNotComplete = "815141"
-        IdealPaymentsCannotBeVaulted = "915150"
-        PaymentInstrumentWithExternalVaultIsInvalid = "915176"
-        DiscountAmountFormatIsInvalid = "915159"
-        DiscountAmountCannotBeNegative = "915160"
-        DiscountAmountIsTooLarge = "915161"
-        ShippingAmountFormatIsInvalid = "915162"
-        ShippingAmountCannotBeNegative = "915163"
-        ShippingAmountIsTooLarge = "915164"
-        ShipsFromPostalCodeIsTooLong = "915165"
-        ShipsFromPostalCodeIsInvalid = "915166"
-        ShipsFromPostalCodeInvalidCharacters = "915167"
+        LineItemsExpected = "915158"
         MerchantAccountDoesNotMatch3DSecureMerchantAccount = "91584"
-        MerchantAccountDoesNotMatchIdealPaymentMerchantAccount = "915143"
         MerchantAccountDoesNotSupportMOTO = "91558"
         MerchantAccountDoesNotSupportRefunds = "91547"
         MerchantAccountIdDoesNotMatchSubscription = "915180"
         MerchantAccountIdIsInvalid = "91513"
-        MerchantAccountIsSusped = "91514" # Deprecated
         MerchantAccountIsSuspended = "91514"
-        MerchantAccountNameIsInvalid = "91513" # Deprecated
-        OrderIdDoesNotMatchIdealPaymentOrderId = "91503"
-        OrderIdIsRequiredWithIdealPayment = "91502"
+        NoNetAmountToPerformAuthAdjustment = "95606"
         OrderIdIsTooLong = "91501"
         PayPalAuthExpired = "91579"
         PayPalNotEnabled = "91576"
         PayPalVaultRecordMissingData = "91583"
         PaymentInstrumentNotSupportedByMerchantAccount = "91577"
         PaymentInstrumentTypeIsNotAccepted = "915101"
+        PaymentInstrumentWithExternalVaultIsInvalid = "915176"
         PaymentMethodConflict = "91515"
-        PaymentMethodConflictWithVenmoSDK = "91549"
+        PaymentMethodConflictWithVenmoSDK = "91549" # NEXT_MJOR_VERSION remove this code
         PaymentMethodDoesNotBelongToCustomer = "91516"
         PaymentMethodDoesNotBelongToSubscription = "91527"
         PaymentMethodNonceCardTypeIsNotAccepted = "91567"
@@ -553,15 +580,23 @@ class ErrorCodes(object):
         ProcessorAuthorizationCodeCannotBeSet = "91519"
         ProcessorAuthorizationCodeIsInvalid = "81520"
         ProcessorDoesNotSupportAuths = "915104"
+        ProcessorDoesNotSupportAuthAdjustment = "915222"
         ProcessorDoesNotSupportCredits = "91546"
+        ProcessorDoesNotSupportIncrementalAuth = "915220"
+        ProcessorDoesNotSupportMotoForCardType = "915195"
+        ProcessorDoesNotSupportPartialAuthReversal = "915221"
         ProcessorDoesNotSupportPartialSettlement = "915102"
-        ProcessorDoesNotSupportUpdatingOrderId = "915107"
         ProcessorDoesNotSupportUpdatingDescriptor = "915108"
+        ProcessorDoesNotSupportUpdatingOrderId = "915107"
         ProcessorDoesNotSupportUpdatingTransactionDetails = "915130"
         ProcessorDoesNotSupportVoiceAuthorizations = "91545"
+        ProductSkuIsInvalid = "915202"
         PurchaseOrderNumberIsInvalid = "91548"
         PurchaseOrderNumberIsTooLong = "91537"
         RefundAmountIsTooLarge = "91521"
+        RefundAuthHardDeclined = "915200"
+        RefundAuthSoftDeclined = "915201"
+        ScaExemptionInvalid = "915213"
         ServiceFeeAmountCannotBeNegative = "91554"
         ServiceFeeAmountFormatIsInvalid = "91555"
         ServiceFeeAmountIsTooLarge = "91556"
@@ -571,36 +606,51 @@ class ErrorCodes(object):
         SettlementAmountIsLessThanServiceFeeAmount = "91551"
         SettlementAmountIsTooLarge = "91522"
         ShippingAddressDoesntMatchCustomer = "91581"
+        ShippingAmountCannotBeNegative = "915163"
+        ShippingAmountFormatIsInvalid = "915162"
+        ShippingAmountIsTooLarge = "915164"
+        ShippingMethodIsInvalid = "915203"
+        ShippingPhoneNumberIsInvalid = "915204"
+        ShipsFromPostalCodeInvalidCharacters = "915167"
+        ShipsFromPostalCodeIsInvalid = "915166"
+        ShipsFromPostalCodeIsTooLong = "915165"
         SubMerchantAccountRequiresServiceFeeAmount = "91553"
         SubscriptionDoesNotBelongToCustomer = "91529"
         SubscriptionIdIsInvalid = "91528"
         SubscriptionStatusMustBePastDue = "91531"
         TaxAmountCannotBeNegative = "81534"
         TaxAmountFormatIsInvalid = "81535"
+        TaxAmountIsRequiredForAibSwedish = "815224"
         TaxAmountIsTooLarge = "81536"
         ThreeDSecureAuthenticationFailed = "81571"
+        ThreeDSecureAuthenticationIdDoesntMatchNonceThreeDSecureAuthentication = "915198"
+        ThreeDSecureAuthenticationIdIsInvalid = "915196"
+        ThreeDSecureAuthenticationIdWithThreeDSecurePassThruIsInvalid = "915199"
+        ThreeDSecureAuthenticationResponseIsInvalid = "915120"
+        ThreeDSecureCavvAlgorithmIsInvalid = "915122"
+        ThreeDSecureCavvIsRequired = "915116"
+        ThreeDSecureDirectoryResponseIsInvalid = "915121"
+        ThreeDSecureEciFlagIsInvalid = "915114"
+        ThreeDSecureEciFlagIsRequired = "915113"
+        ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
         ThreeDSecureTokenIsInvalid = "91568"
         ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
-        ThreeDSecureEciFlagIsRequired = "915113"
-        ThreeDSecureCavvIsRequired = "915116"
+        ThreeDSecureTransactionPaymentMethodDoesntMatchThreeDSecureAuthenticationPaymentMethod = "915197"
         ThreeDSecureXidIsRequired = "915115"
-        ThreeDSecureEciFlagIsInvalid = "915114"
-        ThreeDSecureAuthenticationResponseIsInvalid = "915120"
-        ThreeDSecureDirectoryResponseIsInvalid = "915121"
-        ThreeDSecureCavvAlgorithmIsInvalid = "915122"
-        ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
         TooManyLineItems = "915157"
-        LineItemsExpected = "915158"
+        TransactionIsNotEligibleForAdjustment = "915219"
+        TransactionMustBeInStateAuthorized = "915218"
+        TransactionSourceIsInvalid = "915133"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
         UsBankAccountNonceMustBePlaidVerified = "915171"
         UsBankAccountNotVerified = "915172"
-        TransactionSourceIsInvalid = "915133"
 
         class ExternalVault(object):
             StatusIsInvalid = "915175"
             StatusWithPreviousNetworkTransactionIdIsInvalid = "915177"
+            # NEXT_MAJOR_VERSION remove this validation error as it is no longer returned by the gateway
             CardTypeIsInvalid = "915178"
             PreviousNetworkTransactionIdIsInvalid = "915179"
 
@@ -699,10 +749,9 @@ class ErrorCodes(object):
         class LineItem(object):
             CommodityCodeIsTooLong = "95801"
             DescriptionIsTooLong = "95803"
+            DiscountAmountCannotBeNegative = "95806"
             DiscountAmountFormatIsInvalid = "95804"
             DiscountAmountIsTooLarge = "95805"
-            DiscountAmountMustBeGreaterThanZero = "95806" # Deprecated as the amount may be zero.
-            DiscountAmountCannotBeNegative = "95806"
             KindIsInvalid = "95807"
             KindIsRequired = "95808"
             NameIsRequired = "95822"
@@ -711,22 +760,25 @@ class ErrorCodes(object):
             QuantityFormatIsInvalid = "95810"
             QuantityIsRequired = "95811"
             QuantityIsTooLarge = "95812"
+            TaxAmountCannotBeNegative = "95829"
+            TaxAmountFormatIsInvalid = "95827"
+            TaxAmountIsTooLarge = "95828"
             TotalAmountFormatIsInvalid = "95813"
             TotalAmountIsRequired = "95814"
             TotalAmountIsTooLarge = "95815"
             TotalAmountMustBeGreaterThanZero = "95816"
+            UPCCodeIsMissing = "95830"
+            UPCCodeIsTooLong = "95831"
+            UPCTypeIsInvalid = "95833"
+            UPCTypeIsMissing = "95832"
             UnitAmountFormatIsInvalid = "95817"
             UnitAmountIsRequired = "95818"
             UnitAmountIsTooLarge = "95819"
             UnitAmountMustBeGreaterThanZero = "95820"
             UnitOfMeasureIsTooLarge = "95821"
+            UnitTaxAmountCannotBeNegative = "95826"
             UnitTaxAmountFormatIsInvalid = "95824"
             UnitTaxAmountIsTooLarge = "95825"
-            UnitTaxAmountMustBeGreaterThanZero = "95826" # Deprecated as the amount may be zero.
-            UnitTaxAmountCannotBeNegative = "95826"
-            TaxAmountFormatIsInvalid = "95827"
-            TaxAmountIsTooLarge = "95828"
-            TaxAmountCannotBeNegative = "95829"
 
     class UsBankAccountVerification(object):
         NotConfirmable = "96101"
@@ -735,3 +787,12 @@ class ErrorCodes(object):
         TooManyConfirmationAttempts = "96104"
         UnableToConfirmDepositAmounts = "96105"
         InvalidDepositAmounts = "96106"
+
+    class RiskData(object):
+        # NEXT_MAJOR_VERSION Remove CustomerBrowserIsTooLong code as it is no longer used
+        CustomerBrowserIsTooLong = "94701"
+        CustomerDeviceIdIsTooLong = "94702"
+        CustomerLocationZipInvalidCharacters = "94703"
+        CustomerLocationZipIsInvalid = "94704"
+        CustomerLocationZipIsTooLong = "94705"
+        CustomerTenureIsTooLong = "94706"
