@@ -1,3 +1,4 @@
+from braintree.blik_alias import BlikAlias
 from braintree.resource import Resource
 from braintree.transaction import Transaction
 
@@ -7,3 +8,5 @@ class LocalPaymentCompleted(Resource):
 
         if "transaction" in attributes:
             self.transaction = Transaction(gateway, attributes.pop("transaction"))
+        if "blik_aliases" in attributes:
+            self.blik_aliases = [BlikAlias(gateway, blik_alias) for blik_alias in self.blik_aliases]
