@@ -1,15 +1,20 @@
 
 class PaymentInstrumentType():
-    PayPalAccount = "paypal_account"
-    EuropeBankAccount = "europe_bank_account"
-    CreditCard = "credit_card"
-    CoinbaseAccount = "coinbase_account"
-    ApplePayCard = "apple_pay_card"
-    AndroidPayCard = "android_pay_card"
+    # NEXT_MAJOR_VERSION remove amex express checkout, masterpass, 
+    # and SamsungPayCard. They have been deprecated
     AmexExpressCheckoutCard = "amex_express_checkout_card"
-    VenmoAccount = "venmo_account"
-    UsBankAccount = "us_bank_account"
-    VisaCheckoutCard = "visa_checkout_card"
-    MasterpassCard = "masterpass_card"
-    SamsungPayCard = "samsung_pay_card"
+    AndroidPayCard = "android_pay_card"
+    ApplePayCard = "apple_pay_card"
+    CreditCard = "credit_card"
+    EuropeBankAccount = "europe_bank_account"
     LocalPayment = "local_payment"
+    MasterpassCard = "masterpass_card"
+    MetaCheckoutCard = "meta_checkout_card"
+    MetaCheckoutToken = "meta_checkout_token"
+    PayPalAccount = "paypal_account"
+    PayPalHere = "paypal_here"
+    SamsungPayCard = "samsung_pay_card"
+    SepaDirectDebitAccount = "sepa_debit_account"
+    UsBankAccount = "us_bank_account"
+    VenmoAccount = "venmo_account"
+    VisaCheckoutCard = "visa_checkout_card"
