@@ -1,7 +1,11 @@
 import re
 import string
+import sys
 from braintree.attribute_getter import AttributeGetter
 
+text_type = str
+raw_type = bytes
+
 class Resource(AttributeGetter):
     @staticmethod
     def verify_keys(params, signature):
@@ -15,9 +19,11 @@ class Resource(AttributeGetter):
             keys_string = ", ".join(invalid_keys)
             raise KeyError("Invalid keys: " + keys_string)
 
+    # NEXT_MAJOR_VERSION this method misses a check for param keys that have an empty value
+    # Add a check for a val of length 0 for both types, if true, full_key should be appended
     @staticmethod
     def __flattened_params_keys(params, parent=None):
-        if isinstance(params, str):
+        if isinstance(params, text_type) or isinstance(params, raw_type):
             return [ "%s[%s]" % (parent, params) ]
         else:
             keys = []
@@ -38,19 +44,23 @@ class Resource(AttributeGetter):
         for item in signature:
             if isinstance(item, dict):
                 for key, val in item.items():
-                    full_key = parent + "[" + key + "]" if parent else key
+                    full_key = '{0}[{1}]'.format(parent, key) if parent else key
                     flat_sig += Resource.__flattened_signature(val, full_key)
             else:
-                full_key = parent + "[" + item + "]" if parent else item
+                full_key = '{0}[{1}]'.format(parent, item) if parent else item
                 flat_sig.append(full_key)
         return flat_sig
 
     @staticmethod
     def __remove_wildcard_keys(allowed_keys, invalid_keys):
-        wildcard_keys = [re.sub("(?<=[^\\\\])_", "\\_", re.escape(key)).replace("\\[\\_\\_any\\_key\\_\\_\\]", "\\[[\w-]+\\]") for key in allowed_keys if re.search("\\[__any_key__\\]", key)]
+        wildcard_keys = [
+            re.sub(r"(?<=[^\\])_", "\\_", re.escape(key)).replace(r"\[\_\_any\_key\_\_\]", r"\[[\w.-]+\]")
+            for key in allowed_keys
+            if re.search(r"\[__any_key__\]", key)
+        ]
         new_keys = []
         for key in invalid_keys:
-            if len([match for match in wildcard_keys if re.match("\A" + match + "\Z", key)]) == 0:
+            if len([match for match in wildcard_keys if re.match(r"\A" + match + r"\Z", key)]) == 0:
                 new_keys.append(key)
         return new_keys
 
