@@ -1,17 +1,22 @@
+import braintree
+from braintree.exceptions.unexpected_error import UnexpectedError
+
 class ResourceCollection(object):
     """
-    A class representing results from a search.  Iterate over the results by calling items::
+    A class representing results from a search. Supports the iterator protocol::
 
         results = braintree.Transaction.search("411111")
-        for transaction in results.items:
+        for transaction in results:
             print transaction.id
     """
 
     def __init__(self, query, results, method):
-        self.__page_size = results["search_results"]["page_size"]
+        if "search_results" not in results:
+            raise UnexpectedError("Unprocessable entity due to an invalid request")
         self.__ids = results["search_results"]["ids"]
-        self.__query = query
         self.__method = method
+        self.__page_size = results["search_results"]["page_size"]
+        self.__query = query
 
     @property
     def maximum_size(self):
@@ -33,6 +38,14 @@ class ResourceCollection(object):
             for item in self.__method(self.__query, batch):
                 yield item
 
+    @property
+    def ids(self):
+        """ Returns the list of ids in the search result. """
+        return self.__ids
+
+    def __iter__(self):
+        return self.items
+
     def __batch_ids(self):
         for i in range(0, len(self.__ids), self.__page_size):
                 yield self.__ids[i:i+self.__page_size]
