@@ -5,7 +5,7 @@ if [[ "$1" == "http" ]]; then
 fi
 
 if [[ "$1" == "python3" ]]; then
-  /usr/local/lib/python3.3/bin/nosetests-3.3
+  /usr/local/lib/python3.3/bin/python3 -m unittest discover
 else
   env rake $python_tests --trace
 fi
