@@ -31,7 +31,6 @@ class TestSubscription(unittest.TestCase):
         subscription = result.subscription
         self.assertNotEqual(None, re.search(r"\A\w{6}\Z", subscription.id))
         self.assertEqual(Decimal("12.34"), subscription.price)
-        self.assertEqual(Decimal("12.34"), subscription.next_bill_amount)
         self.assertEqual(Decimal("12.34"), subscription.next_billing_period_amount)
         self.assertEqual(Subscription.Status.Active, subscription.status)
         self.assertEqual("integration_trialless_plan", subscription.plan_id)
@@ -564,9 +563,9 @@ class TestSubscription(unittest.TestCase):
         found_subscription = Subscription.find(subscription.id)
         self.assertEqual(subscription.id, found_subscription.id)
 
-    @raises_with_regexp(NotFoundError, "subscription with id 'bad_token' not found")
     def test_find_with_invalid_token(self):
-        Subscription.find("bad_token")
+        with self.assertRaisesRegex(NotFoundError, "subscription with id 'bad_token' not found"):
+            Subscription.find("bad_token")
 
     def test_update_creates_a_prorated_transaction_when_merchant_is_set_to_prorate(self):
         result = Subscription.update(self.updateable_subscription.id, {
@@ -744,11 +743,11 @@ class TestSubscription(unittest.TestCase):
         self.assertEqual(1, len(id_errors))
         self.assertEqual("81906", id_errors[0].code)
 
-    @raises(NotFoundError)
     def test_update_raises_error_when_subscription_not_found(self):
-        Subscription.update("notfound", {
-            "id": "newid",
-        })
+        with self.assertRaises(NotFoundError):
+            Subscription.update("notfound", {
+                "id": "newid",
+            })
 
     def test_update_allows_overriding_of_inherited_add_ons_and_discounts(self):
         subscription = Subscription.create({
@@ -1035,9 +1034,9 @@ class TestSubscription(unittest.TestCase):
         self.assertTrue(len(status_errors), 1)
         self.assertEqual("81905", status_errors[0].code)
 
-    @raises(NotFoundError)
     def test_cancel_raises_not_found_error_with_bad_subscription(self):
-        Subscription.cancel("notreal")
+        with self.assertRaises(NotFoundError):
+            Subscription.cancel("notreal")
 
     def test_search_with_argument_list_rather_than_literal_list(self):
         trial_subscription = Subscription.create({
@@ -1309,23 +1308,6 @@ class TestSubscription(unittest.TestCase):
         self.assertTrue(TestHelper.includes(collection, subscription_found))
         self.assertFalse(TestHelper.includes(collection, subscription_not_found))
 
-    def test_retryCharge_without_amount__deprecated(self):
-        subscription = Subscription.create({
-            "payment_method_token": self.credit_card.token,
-            "plan_id": TestHelper.trialless_plan["id"],
-        }).subscription
-        TestHelper.make_past_due(subscription)
-
-        result = Subscription.retryCharge(subscription.id)
-
-        self.assertTrue(result.is_success)
-        transaction = result.transaction
-
-        self.assertEqual(subscription.price, transaction.amount)
-        self.assertNotEqual(None, transaction.processor_authorization_code)
-        self.assertEqual(Transaction.Type.Sale, transaction.type)
-        self.assertEqual(Transaction.Status.Authorized, transaction.status)
-
     def test_retry_charge_without_amount(self):
         subscription = Subscription.create({
             "payment_method_token": self.credit_card.token,
@@ -1343,23 +1325,6 @@ class TestSubscription(unittest.TestCase):
         self.assertEqual(Transaction.Type.Sale, transaction.type)
         self.assertEqual(Transaction.Status.Authorized, transaction.status)
 
-    def test_retryCharge_with_amount__deprecated(self):
-        subscription = Subscription.create({
-            "payment_method_token": self.credit_card.token,
-            "plan_id": TestHelper.trialless_plan["id"],
-        }).subscription
-        TestHelper.make_past_due(subscription)
-
-        result = Subscription.retryCharge(subscription.id, Decimal(TransactionAmounts.Authorize))
-
-        self.assertTrue(result.is_success)
-        transaction = result.transaction
-
-        self.assertEqual(Decimal(TransactionAmounts.Authorize), transaction.amount)
-        self.assertNotEqual(None, transaction.processor_authorization_code)
-        self.assertEqual(Transaction.Type.Sale, transaction.type)
-        self.assertEqual(Transaction.Status.Authorized, transaction.status)
-
     def test_retry_charge_with_amount(self):
         subscription = Subscription.create({
             "payment_method_token": self.credit_card.token,
@@ -1447,7 +1412,7 @@ class TestSubscription(unittest.TestCase):
 
     def test_create_fails_with_paypal_future_payment_method_nonce(self):
         result = Subscription.create({
-            "payment_method_nonce": Nonces.PayPalFuturePayment,
+            "payment_method_nonce": Nonces.PayPalBillingAgreement,
             "plan_id": TestHelper.trialless_plan["id"]
         })
 
