@@ -1,3 +1,4 @@
+from unittest.mock import patch
 from tests.test_helper import *
 
 class TestTransactionSearch(unittest.TestCase):
@@ -273,6 +274,67 @@ class TestTransactionSearch(unittest.TestCase):
         self.assertEqual(transaction.payment_instrument_type, PaymentInstrumentType.LocalPayment)
         self.assertEqual(transaction.id, collection.first.id)
 
+    def test_advanced_search_with_payment_instrument_type_is_sepa_debit_account(self):
+        transaction = Transaction.sale({
+            "amount": TransactionAmounts.Authorize,
+            "options": {
+                "submit_for_settlement": True,
+            },
+            "payment_method_nonce": Nonces.SepaDirectDebit
+        }).transaction
+
+        collection = Transaction.search(
+            TransactionSearch.id == transaction.id,
+            TransactionSearch.payment_instrument_type == "SEPADebitAccount"
+        )
+
+        self.assertEqual(transaction.payment_instrument_type, PaymentInstrumentType.SepaDirectDebitAccount)
+        self.assertEqual(transaction.id, collection.first.id)
+
+    def test_advanced_search_with_sepa_debit_paypal_v2_order_id(self):
+        transaction = Transaction.sale({
+            "amount": TransactionAmounts.Authorize,
+            "options": {
+                "submit_for_settlement": True,
+            },
+            "payment_method_nonce": Nonces.SepaDirectDebit
+        }).transaction
+
+        collection = Transaction.search(
+            TransactionSearch.id == transaction.id,
+            TransactionSearch.sepa_debit_paypal_v2_order_id == transaction.sepa_direct_debit_account_details.paypal_v2_order_id
+        )
+
+        self.assertEqual(transaction.payment_instrument_type, PaymentInstrumentType.SepaDirectDebitAccount)
+        self.assertEqual(transaction.id, collection.first.id)
+
+    def test_advanced_search_with_payment_instrument_type_is_meta_checkout(self):
+        card_tx = Transaction.sale({
+            "amount": TransactionAmounts.Authorize,
+            "options": {
+                "submit_for_settlement": True,
+            },
+            "payment_method_nonce": Nonces.MetaCheckoutCard
+        }).transaction
+
+        token_tx = Transaction.sale({
+            "amount": TransactionAmounts.Authorize,
+            "options": {
+                "submit_for_settlement": True,
+            },
+            "payment_method_nonce": Nonces.MetaCheckoutToken
+        }).transaction
+
+        collection = Transaction.search(
+            TransactionSearch.payment_instrument_type == "MetaCheckout"
+        )
+
+        self.assertTrue(collection.maximum_size >= 2)
+
+        tx_id_map = list(map(lambda x: x.id, collection))
+        self.assertTrue(card_tx.id in tx_id_map)
+        self.assertTrue(token_tx.id in tx_id_map)
+
     def test_advanced_search_with_payment_instrument_type_is_apple_pay(self):
         transaction = Transaction.sale({
             "amount": TransactionAmounts.Authorize,
@@ -287,6 +349,39 @@ class TestTransactionSearch(unittest.TestCase):
         self.assertEqual(transaction.payment_instrument_type, PaymentInstrumentType.ApplePayCard)
         self.assertEqual(transaction.id, collection.first.id)
 
+    def test_advanced_search_with_debit_network(self):
+        transaction = Transaction.sale({
+            "amount": TransactionAmounts.Authorize,
+            "merchant_account_id": TestHelper.pinless_debit_merchant_account_id,
+            #"currency_iso_code": "USD",
+            "payment_method_nonce": Nonces.TransactablePinlessDebitVisa,
+            "options": {
+                "submit_for_settlement": True
+            }
+        }).transaction
+
+        collection = Transaction.search(
+            TransactionSearch.id == transaction.id,
+            TransactionSearch.credit_card_card_type == transaction.credit_card_details.card_type
+        )
+
+        self.assertEqual(1, collection.maximum_size)
+        self.assertEqual(transaction.id, collection.first.id)
+
+        collection = Transaction.search(
+            TransactionSearch.id == transaction.id,
+            TransactionSearch.debit_network.in_list(Constants.get_all_enum_values(CreditCard.DebitNetwork))
+        )
+
+        self.assertEqual(1, collection.maximum_size)
+
+    def test_advanced_search_multiple_value_node_allowed_values_debit_network(self):
+        with self.assertRaisesRegex(AttributeError,
+                "Invalid argument\(s\) for debit_network: noSuchDebitNetwork"):
+            Transaction.search([
+                TransactionSearch.debit_network == "noSuchDebitNetwork"
+            ])
+
     def test_advanced_search_text_node_contains(self):
         transaction = Transaction.sale({
             "amount": TransactionAmounts.Authorize,
@@ -419,9 +514,9 @@ class TestTransactionSearch(unittest.TestCase):
 
         self.assertEqual(0, collection.maximum_size)
 
-    @raises_with_regexp(AttributeError, "Invalid argument\(s\) for created_using: noSuchCreatedUsing")
     def test_advanced_search_multiple_value_node_allowed_values_created_using(self):
-        Transaction.search([TransactionSearch.created_using == "noSuchCreatedUsing"])
+        with self.assertRaisesRegex(AttributeError, "Invalid argument\(s\) for created_using: noSuchCreatedUsing"):
+            Transaction.search([TransactionSearch.created_using == "noSuchCreatedUsing"])
 
     def test_advanced_search_multiple_value_node_credit_card_customer_location(self):
         transaction = Transaction.sale({
@@ -455,12 +550,12 @@ class TestTransactionSearch(unittest.TestCase):
 
         self.assertEqual(0, collection.maximum_size)
 
-    @raises_with_regexp(AttributeError,
-            "Invalid argument\(s\) for credit_card_customer_location: noSuchCreditCardCustomerLocation")
     def test_advanced_search_multiple_value_node_allowed_values_credit_card_customer_location(self):
-        Transaction.search([
-            TransactionSearch.credit_card_customer_location == "noSuchCreditCardCustomerLocation"
-        ])
+        with self.assertRaisesRegex(AttributeError,
+            "Invalid argument\(s\) for credit_card_customer_location: noSuchCreditCardCustomerLocation"):
+            Transaction.search([
+                TransactionSearch.credit_card_customer_location == "noSuchCreditCardCustomerLocation"
+            ])
 
     def test_advanced_search_multiple_value_node_merchant_account_id(self):
         transaction = Transaction.sale({
@@ -586,12 +681,12 @@ class TestTransactionSearch(unittest.TestCase):
         self.assertEqual(transaction.id, collection.first.id)
         self.assertEqual(transaction.credit_card_details.card_type, collection.first.credit_card_details.card_type)
 
-    @raises_with_regexp(AttributeError,
-            "Invalid argument\(s\) for credit_card_card_type: noSuchCreditCardCardType")
     def test_advanced_search_multiple_value_node_allowed_values_credit_card_card_type(self):
-        Transaction.search([
-            TransactionSearch.credit_card_card_type == "noSuchCreditCardCardType"
-        ])
+        with self.assertRaisesRegex(AttributeError,
+                "Invalid argument\(s\) for credit_card_card_type: noSuchCreditCardCardType"):
+            Transaction.search([
+                TransactionSearch.credit_card_card_type == "noSuchCreditCardCardType"
+            ])
 
     def test_advanced_search_multiple_value_node_status(self):
         transaction = Transaction.sale({
@@ -639,9 +734,18 @@ class TestTransactionSearch(unittest.TestCase):
         ])
         print(collection)
 
-    @raises_with_regexp(AttributeError, "Invalid argument\(s\) for status: noSuchStatus")
+    def test_advanced_search_settlement_confirmed_transaction(self):
+        transaction_id = "settlement_confirmed_txn"
+
+        collection = Transaction.search([
+            TransactionSearch.id == transaction_id
+        ])
+
+        self.assertEqual(1, collection.maximum_size)
+
     def test_advanced_search_multiple_value_node_allowed_values_status(self):
-        Transaction.search([TransactionSearch.status == "noSuchStatus"])
+        with self.assertRaisesRegex(AttributeError, "Invalid argument\(s\) for status: noSuchStatus"):
+            Transaction.search([TransactionSearch.status == "noSuchStatus"])
 
     def test_advanced_search_multiple_value_node_source(self):
         transaction = Transaction.sale({
@@ -707,11 +811,11 @@ class TestTransactionSearch(unittest.TestCase):
 
         self.assertEqual(0, collection.maximum_size)
 
-    @raises_with_regexp(AttributeError, "Invalid argument\(s\) for type: noSuchType")
     def test_advanced_search_multiple_value_node_allowed_values_type(self):
-        Transaction.search([
-            TransactionSearch.type == "noSuchType"
-        ])
+        with self.assertRaisesRegex(AttributeError, "Invalid argument\(s\) for type: noSuchType"):
+            Transaction.search([
+                TransactionSearch.type == "noSuchType"
+            ])
 
     def test_advanced_search_multiple_value_node_type_with_refund(self):
         name = "Anabel Atkins%s" % random.randint(1, 100000)
@@ -1004,7 +1108,6 @@ class TestTransactionSearch(unittest.TestCase):
 
         collection = Transaction.search([
             TransactionSearch.id == transaction_id,
-            TransactionSearch.disbursement_date <= disbursement_time
         ])
 
         self.assertEqual(1, collection.maximum_size)
@@ -1012,7 +1115,6 @@ class TestTransactionSearch(unittest.TestCase):
 
         collection = Transaction.search([
             TransactionSearch.id == transaction_id,
-            TransactionSearch.disbursement_date <= future
         ])
 
         self.assertEqual(1, collection.maximum_size)
@@ -1574,8 +1676,95 @@ class TestTransactionSearch(unittest.TestCase):
         self.assertEqual(1, collection.maximum_size)
         self.assertEqual(transaction.id, collection.first.id)
 
-    @raises(DownForMaintenanceError)
-    def test_search_handles_a_search_timeout(self):
-        Transaction.search([
-            TransactionSearch.amount.between("-1100", "1600")
+    def test_advanced_search_can_search_on_store_id_1(self):
+        transaction_id = "contact_visa_transaction"
+
+        collection = Transaction.search([
+            TransactionSearch.id == transaction_id,
+            TransactionSearch.store_id == "store-id"
         ])
+
+        self.assertEqual(1, collection.maximum_size)
+
+        collection = Transaction.search([
+            TransactionSearch.id == transaction_id,
+            TransactionSearch.store_id == "invalid-store-id"
+        ])
+
+        self.assertEqual(0, collection.maximum_size)
+
+    def test_advanced_search_can_search_on_store_ids(self):
+        transaction_id = "contact_visa_transaction"
+
+        collection = Transaction.search([
+            TransactionSearch.id == transaction_id,
+            TransactionSearch.store_ids.in_list(["store-id"])
+        ])
+
+        self.assertEqual(1, collection.maximum_size)
+
+        collection = Transaction.search([
+            TransactionSearch.id == transaction_id,
+            TransactionSearch.store_ids.in_list(["invalid-store-id"])
+        ])
+
+        self.assertEqual(0, collection.maximum_size)
+
+    def test_search_handles_a_search_timeout(self):
+        with self.assertRaises(RequestTimeoutError):
+            Transaction.search([
+                TransactionSearch.amount.between("-1100", "1600")
+            ])
+
+    def test_search_returns_records_from_valid_daterange(self):
+        yesterday = datetime.now() - timedelta(days=1)
+        tomorrow = datetime.now() + timedelta(days=1)
+
+        collection = Transaction.search([
+            TransactionSearch.ach_return_responses_created_at.between(yesterday, tomorrow)
+        ])
+        self.assertEqual(2, collection.maximum_size)
+
+    def test_search_returns_records_from_invalid_daterange(self):
+        day_after_tomorrow = datetime.now() + timedelta(days=1)
+        tomorrow = datetime.now() + timedelta(days=2)
+
+        collection = Transaction.search([
+            TransactionSearch.ach_return_responses_created_at.between(tomorrow, day_after_tomorrow)
+        ])
+        self.assertEqual(0, collection.maximum_size)
+
+    def test_search_returns_records_for_one_reasoncode(self):
+        collection = Transaction.search([
+            TransactionSearch.reason_code.in_list(['R01'])
+        ])
+        self.assertEqual(1, collection.maximum_size)
+
+    def test_search_returns_records_for_multiple_reasoncode(self):
+        collection = Transaction.search([
+            TransactionSearch.reason_code.in_list(['R01', 'R02'])
+        ])
+        self.assertEqual(2, collection.maximum_size)
+
+    def test_search_returns_multiple_records_for_any_reason_code(self):
+        collection = Transaction.search([
+            TransactionSearch.reason_code == Transaction.ReasonCode.ANY_REASON_CODE
+        ])
+        self.assertEqual(2, collection.maximum_size)
+
+    def test_search_retried_transaction(self):
+        result = Transaction.sale({
+            "merchant_account_id": TestHelper.default_merchant_account_id,
+            "amount": TransactionAmounts.Decline,
+            "payment_method_token": "network_tokenized_credit_card",
+            })
+        transaction = result.transaction
+        retry_transaction_id = transaction.retry_ids[0]
+
+        collection = Transaction.search(
+            TransactionSearch.id == retry_transaction_id,
+            TransactionSearch.amount == TransactionAmounts.Decline,
+        )
+        self.assertEqual(1, collection.maximum_size)
+        self.assertIsNotNone(collection.first.retried_transaction_id)
+        self.assertEqual(retry_transaction_id, collection.first.id)
