@@ -2,7 +2,7 @@ from tests.test_helper import *
 
 class TestClientToken(unittest.TestCase):
     def test_credit_card_options_require_customer_id(self):
-        for option in ["verify_card", "make_default", "fail_on_duplicate_payment_method"]:
+        for option in ["fail_on_duplicate_payment_method", "fail_on_duplicate_payment_method_for_customer", "make_default", "verify_card"]:
             with self.assertRaisesRegex(InvalidSignatureError, option):
                 ClientToken.generate({
                     "options": {option: True}
