@@ -31,9 +31,6 @@ class TestExports(unittest.TestCase):
         self.assertNotEqual(braintree.ErrorResult, None)
         self.assertNotEqual(braintree.Errors, None)
         self.assertNotEqual(braintree.EuropeBankAccount, None)
-        # NEXT_MAJOR_VERSION Remove this class as legacy Ideal has been removed/disabled in the Braintree Gateway
-        # DEPRECATED If you're looking to accept iDEAL as a payment method contact accounts@braintreepayments.com for a solution.
-        self.assertNotEqual(braintree.IdealPayment, None)
         self.assertNotEqual(braintree.Merchant, None)
         self.assertNotEqual(braintree.MerchantAccount, None)
         self.assertNotEqual(braintree.MerchantAccountGateway, None)
@@ -62,8 +59,6 @@ class TestExports(unittest.TestCase):
         self.assertNotEqual(braintree.TransactionDetails, None)
         self.assertNotEqual(braintree.TransactionGateway, None)
         self.assertNotEqual(braintree.TransactionSearch, None)
-        self.assertNotEqual(braintree.TransparentRedirect, None)
-        self.assertNotEqual(braintree.TransparentRedirectGateway, None)
         self.assertNotEqual(braintree.UnknownPaymentMethod, None)
         self.assertNotEqual(braintree.UsBankAccount, None)
         self.assertNotEqual(braintree.ValidationErrorCollection, None)
