@@ -821,8 +821,31 @@ class TestWebhooks(unittest.TestCase):
         local_payment_completed = notification.local_payment_completed
 
         self.assertEqual(WebhookNotification.Kind.LocalPaymentCompleted, notification.kind)
-        self.assertEqual("a-payment-id", local_payment_completed.payment_id)
+        self.assertEqual("a-bic", local_payment_completed.bic)
+        self.assertEqual("1234", local_payment_completed.iban_last_chars)
         self.assertEqual("a-payer-id", local_payment_completed.payer_id)
+        self.assertEqual("a-payer-name", local_payment_completed.payer_name)
+        self.assertEqual("a-payment-id", local_payment_completed.payment_id)
+        self.assertEqual("ee257d98-de40-47e8-96b3-a6954ea7a9a4", local_payment_completed.payment_method_nonce)
+        self.assertTrue(isinstance(local_payment_completed.transaction, Transaction))
+
+    def test_local_payment_completed_webhook_blik_one_click(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.LocalPaymentCompleted,
+            "blik_one_click_id"
+        )
+
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+        local_payment_completed = notification.local_payment_completed
+
+        self.assertEqual(WebhookNotification.Kind.LocalPaymentCompleted, notification.kind)
+        self.assertEqual("1234", local_payment_completed.iban_last_chars)
+        self.assertEqual("a-bic", local_payment_completed.bic)
+        self.assertEqual('alias-key-1', local_payment_completed.blik_aliases[0].key)
+        self.assertEqual('alias-label-1', local_payment_completed.blik_aliases[0].label)
+        self.assertEqual("a-payer-id", local_payment_completed.payer_id)
+        self.assertEqual("a-payer-name", local_payment_completed.payer_name)
+        self.assertEqual("a-payment-id", local_payment_completed.payment_id)
         self.assertEqual("ee257d98-de40-47e8-96b3-a6954ea7a9a4", local_payment_completed.payment_method_nonce)
         self.assertTrue(isinstance(local_payment_completed.transaction, Transaction))
 
